pub struct MusigKeyAggCache(/* private fields */);Implementations
Sourceimpl MusigKeyAggCache
impl MusigKeyAggCache
Sourcepub fn cmp_fast_unstable(&self, other: &Self) -> Ordering
pub fn cmp_fast_unstable(&self, other: &Self) -> Ordering
Like cmp::Ord but faster and with no guarantees across library versions.
The inner byte array of Self is passed across the FFI boundry, as such there are
no guarantees on its layout and it is subject to change across library versions,
even minor versions. For this reason comparison function implementations (e.g.
Ord, PartialEq) take measures to ensure the data will remain constant (e.g., by
serializing it to a guaranteed format). This means they may be slow, this function
provides a faster comparison if you know that your types come from the same library
version.
Sourcepub fn eq_fast_unstable(&self, other: &Self) -> bool
pub fn eq_fast_unstable(&self, other: &Self) -> bool
Like cmp::Eq but faster and with no guarantees across library versions.
The inner byte array of Self is passed across the FFI boundry, as such there are
no guarantees on its layout and it is subject to change across library versions,
even minor versions. For this reason comparison function implementations (e.g.
Ord, PartialEq) take measures to ensure the data will remain constant (e.g., by
serializing it to a guaranteed format). This means they may be slow, this function
provides a faster equality check if you know that your types come from the same
library version.